
	set more off, perm
	

	
	do "pgm/00_Globals.do"	
	
	** RUN DO FILE of COST ESTIMATES
	do "pgm/06_WTP.do"


	
	************************* 
	**** Set assumptions ****
	*************************
	
	global wtp_assumption cd_out  // cd_out no_cd_out   
	global pastcc_assumption pastm // pastlb pastub pastm comment if running alternatives
	global polcc_assumption polub // polub pollb comment if running alternatives
	global months m11 // m11 m9 comment if running alternatives
	global taxrate_assumption jo // jo id
	global correlation 1 // comment if running sensitivity
	local bootstrap_reps = 1000
	local inf = .

	
	
	local months = "$months"
	local typecost = "$typecost"
	local wtp_assumption = "$wtp_assumption"
	local polcc_assumption = "$polcc_assumption"
	local pastcc_assumption = "$pastcc_assumption"
	local taxrate_assumption = "$taxrate_assumption"
	local correlation = "$correlation"

	**********************
	*** Set parameters ***
	**********************
	
	* Wage impact on mothers
	local wage_effect_b = 0.031
	local wage_effect_se = 0.01
	
	local pre_reform_monthly_wage_w = 1612
	local pre_reform_annual_wage_w = `pre_reform_monthly_wage_w'*12
	
	if "`taxrate_assumption'"== "jo" {

	local pre_reform_taxable_inc_hh = 12474
	local post_reform_taxable_inc_hh = 12663
	local avg_tmi = 0.094
	local avg_share = 3.04
	
	local base_csg = 0.9825
	local csg = 0.068
	local gross_rate = 1.28
	local gross_wage_pre = `pre_reform_annual_wage_w' * `gross_rate'
	local gross_wage_post = `pre_reform_annual_wage_w' * `gross_rate' * (1 + `wage_effect_b' )
	
	* Fiscal externality calculations
	* CSG
	local rev_csg_pre=`gross_wage_pre'*`csg'*`base_csg'
	local rev_csg_post=`gross_wage_post'*`csg'*`base_csg'
	local fe_csg=`rev_csg_post'-`rev_csg_pre'	
	di `fe_csg'
	local fe_csg_se=`wage_effect_se'*`pre_reform_annual_wage_w'*`gross_rate'*`csg'*`base_csg'
	di `fe_csg_se'
	
	* Income tax
	local tax_reve_preref_b=`pre_reform_taxable_inc_hh' * `avg_tmi' * `avg_share'
	local tax_reve_postref_b=`post_reform_taxable_inc_hh'*`avg_tmi'*`avg_share'
	di `tax_reve_preref_b'
	di `tax_reve_postref_b'
	local fe_ir=`tax_reve_postref_b'-`tax_reve_preref_b'
	di `fe_ir'
	local fe_ir_se=`wage_effect_se'*`pre_reform_annual_wage_w'*`avg_tmi' 
	di `fe_ir_se'
	
	local FE_b=`fe_csg'+`fe_ir'
		
	di `FE_b'
	
	}
	
	if "`taxrate_assumption'"== "id" {

	local avg_tmi = 0.15
	local post_reform_annual_wage_w = `pre_reform_monthly_wage_w'*12*1.031
	local base_csg = 0.9825
	local csg = 0.068
	local gross_rate = 1.28
	local gross_wage_pre = `pre_reform_annual_wage_w' * `gross_rate'
	local gross_wage_post = `pre_reform_annual_wage_w' * `gross_rate' * (1 + `wage_effect_b' )
	
	* Fiscal externality calculations
	* CSG
	local rev_csg_pre=`gross_wage_pre'*`csg'*`base_csg'
	local rev_csg_post=`gross_wage_post'*`csg'*`base_csg'
	local fe_csg=`rev_csg_post'-`rev_csg_pre'	
	di `fe_csg'
	local fe_csg_se=`wage_effect_se'*`pre_reform_annual_wage_w'*`gross_rate'*`csg'*`base_csg'
	di `fe_csg_se'
	
	* Income tax
	local tax_reve_preref_b=`pre_reform_annual_wage_w' * `avg_tmi' 
	local tax_reve_postref_b=`post_reform_annual_wage_w'*`avg_tmi'

	local fe_ir=`tax_reve_postref_b'-`tax_reve_preref_b'
	di `fe_ir'
	local fe_ir_se=`wage_effect_se'*`pre_reform_annual_wage_w'*`avg_tmi' 
	di `fe_ir_se'
	
	local FE_b=`fe_csg'+`fe_ir'
		
	di `FE_b'
	
	
	}
	* Childcare cost

	
	
	if "`months'"== "m9" {
		local childcare_cost_ub = $costA9W_max
		local childcare_cost_lb = $costA9W_min
		local childcare_cost_mean = $costA9W_m
		}
	
	if "`months'"== "m11" {
		local childcare_cost_ub = $costA11W_max 
		local childcare_cost_lb = $costA11W_min
		local childcare_cost_mean = $costA11W_m
		}
		
	di `childcare_cost_mean'
	
	if "`wtp_assumption'"== "cd_out" {
	local crowding_out=0.59	// 59% women working on Wednesdays (From French LFS 2009-2013)
		}
	if "`wtp_assumption'"== "no_crowd_out" {
	local crowding_out=1	// 59% women working on Wednesdays (From French LFS 2009-2013)
		}
	
	
	if "`pastcc_assumption'"== "pastub" {
		local childcare_cost=`childcare_cost_ub'
		}
		
	if "`pastcc_assumption'"== "pastlb" {
		local childcare_cost=`childcare_cost_lb'
		}	
		
	if "`pastcc_assumption'"== "pastm" {
		local childcare_cost=`childcare_cost_mean'
		}	
		
	di `childcare_cost'	
		
	* Cost of policy

	local cost_pol_ub_b = 211.554 // from Cassette and Farvaque (2019)
	local cost_pol_lb_b = 177.049
		
	local cost_pol_ub_se = 22.819
	local cost_pol_lb_se = 33.3
	
	if "`polcc_assumption'"== "polub" {
		local program_cost=`cost_pol_ub_b'
		local program_cost_se=`cost_pol_ub_se'
		}
		
	if "`polcc_assumption'"== "pollb" {
		local program_cost=`cost_pol_lb_b'
		local program_cost_se=`cost_pol_lb_se'		
		}	 
	
	di `program_cost'

	

	
	* Net Cost Calculations
	
	local total_cost=`program_cost'-`FE_b'
	local total_cost_se=sqrt((`program_cost_se')^2+(`fe_ir_se')^2+ (`fe_csg_se')^2-2*`correlation'*`program_cost_se'*`fe_ir_se' -2*`correlation'*`program_cost_se'*`fe_csg_se' +2*`correlation'*`fe_ir_se'*`fe_csg_se')
	
	di `total_cost'
	di `total_cost_se'
	
	* WTP Calculations
		
	if "`wtp_assumption'"== "cd_out" {
		local WTP=`childcare_cost'*`crowding_out'
		}

	if "`wtp_assumption'"== "no_cd_out" {
		local WTP=`childcare_cost'
		}
	
	if "`wtp_assumption'"== "child_effect" {
		local WTP=`childcare_cost'*`crowding_out'+`childeffect'
		}

	*************************
	*** MVPF Calculations ***
	*************************	
	
	di `WTP'
			
			
	drawnorm cost, seed(1234) n(`bootstrap_reps') clear  means(`total_cost') sds(`total_cost_se') 

	gen wtp=`WTP'
	g mvpf = wtp/cost
	su mvpf
	replace mvpf = `inf' if wtp>0 & cost <=0
	replace mvpf = -`inf' if wtp<0 & cost ==0
	
	local cost = cost
	local wtp = wtp
	
	*Fix true mvpf to new infinity if required
	if `wtp' > 0 & `cost' <= 0 local mvpf = `inf'
	if `wtp' < 0 & `cost' == 0 local mvpf = -`inf'
	
	*Estimate Efron bias corrected CIs 
	su mvpf
	local mvpf_sd = r(sd)
	sort mvpf
	g pctile = _n/_N
	
	su mvpf , d
	
	
	
	
